const svg = d3.select('svg'),
  margin = { top: 20, right: 20, bottom: 30, left: 60 },
  width = +svg.attr('width') - margin.left - margin.right,
  height = +svg.attr('height') - margin.top - margin.bottom;

const x = d3.scaleLinear().range([0, width]);
const y = d3.scaleLinear().range([height, 0]);

const g = svg
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

const csvUrl =
  'https://gist.githubusercontent.com/Mukunda799/770cd9be627ec3ec6c8de3e3e3aaba7a/raw/3d909ff2bae1fecbb11df95e3501d74ae253ff37/Iphone_sales.csv';
d3.csv(csvUrl).then((data) => {
  data.forEach((d) => {
    d['Sale Price'] = +d['Sale Price']; // Convert Sale Price to numeric
    d['Number Of Ratings'] = +d['Number Of Ratings']; // Convert Number Of Ratings to numeric
  });

  x.domain(d3.extent(data, (d) => d['Sale Price'])).nice();
  y.domain(
    d3.extent(data, (d) => d['Number Of Ratings']),
  ).nice();

  g.append('g')
    .attr('class', 'axis axis--x')
    .attr('transform', `translate(0,${height})`)
    .call(d3.axisBottom(x))
    .append('text')
    .attr('fill', '#000')
    .attr('x', width)
    .attr('dy', '2.5em')
    .attr('text-anchor', 'end')
    .text('Sale Price');

  g.append('g')
    .attr('class', 'axis axis--y')
    .call(d3.axisLeft(y))
    .append('text')
    .attr('fill', '#000')
    .attr('y', -40)
    .attr('dy', '0.71em')
    .attr('text-anchor', 'end')
    .text('Number Of Ratings');
  // X-axis label
  svg
    .append('text')
    .attr('text-anchor', 'middle')
    .attr('x', width / 2)
    .attr('y', height - 20)
    .style('fill', 'black')
    .text('Sale Price');

  // Y-axis label
  svg
    .append('text')
    .attr('text-anchor', 'middle')
    .attr(
      'transform',
      `translate(15,${height / 2})rotate(-90)`,
    )
    .style('fill', 'black')
    .text('No of Ratings');

  g.selectAll('.dot')
    .data(data)
    .enter()
    .append('circle')
    .attr('class', 'dot')
    .attr('cx', (d) => x(d['Sale Price']))
    .attr('cy', (d) => y(d['Number Of Ratings']))
    .attr('r', 3.5)
    .style('fill', (d) => color(d['Product Name'])); // Apply color scale if desired
});
